
(function () {
    // 初始化命名空间
    window.QwenChat = window.QwenChat || {};
    const bridgeName = 'QwenChat';

    // 回调系统
    window.QwenChat.__callbacks = {};
    window.QwenChat.__callbackSuccess = function (id, result) {
        if (window.QwenChat.__callbacks[id]) {
            window.QwenChat.__callbacks[id].resolve(result);
            delete window.QwenChat.__callbacks[id];
        }
    };
    window.QwenChat.__callbackError = function (id, error) {
        if (window.QwenChat.__callbacks[id]) {
            window.QwenChat.__callbacks[id].reject(error);
            delete window.QwenChat.__callbacks[id];
        }
    };

    // 平台检测
    const isIOS = /iPad|iPhone|iPod/.test(navigator.userAgent) && !window.MSStream;
    const isAndroid = navigator.userAgent.indexOf('Android') > -1;

    function formatArgument(arg) {
        // 根据类型处理
        if (Array.isArray(arg)) {
            // 数组
        }
        else if (Object.prototype.toString.call(arg) === '[object Object]') {
            return JSON.stringify(arg);
        }

        return arg;
    }

    // 动态方法代理
    window.QwenChat = new Proxy(window.QwenChat, {
        get: function (target, prop, receiver) {
            if (prop in target) return target[prop];

            return function (...args) {
                return new Promise((resolve, reject) => {
                    const callbackId = `prop_${Date.now()}_${Math.random().toString(36).slice(2)}`;
                    window.QwenChat.__callbacks[callbackId] = { resolve, reject };

                    if (isIOS) {
                        window.webkit.messageHandlers[bridgeName].postMessage({
                            method: prop,
                            args: args,
                            callbackId: callbackId
                        });
                    } else if (isAndroid && window.QwenChatAndroid) {
                        window.QwenChatAndroid.postMessage(
                            prop,
                            formatArgument(args[0]),
                            callbackId
                        );
                        console.log('Android:', prop, args, callbackId);
                    } else {
                        reject(new Error('Bridge not available'));
                    }
                });
            };
        }
    });
})();